Wire

Struct Wire 

pub struct Wire<ReqId, Target, Req, Resp, E, Ctx> { /* private fields */ }
Wire provides an interconnect to support integration testing of Mux based implementations

Implementations

Source

impl<ReqId, Target, Req, Resp, E, Ctx> Wire<ReqId, Target, Req, Resp, E, Ctx>
where ReqId: Clone + Hash + Eq + PartialEq + Debug + Send + 'static, Target: Clone + Hash + PartialEq + Eq + Send + 'static, Req: PartialEq + Debug + Send + 'static, Resp: PartialEq + Debug + Send + 'static, E: PartialEq + Debug + Send + 'static, Ctx: Clone + PartialEq + Debug + Send + 'static,

pub fn new() -> Wire<ReqId, Target, Req, Resp, E, Ctx>

Create a new Wire interconnect

pub fn connector( &mut self, target: Target, ) -> WireMux<ReqId, Target, Req, Resp, E, Ctx>

Create a new connector for the provided target address